#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 warp-tls
version:              3.3.0
visibility:           public
id:                   warp-tls-3.3.0-LX9P84vetWr8NjV1La0gY0
key:                  warp-tls-3.3.0-LX9P84vetWr8NjV1La0gY0
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             HTTP over TLS support for Warp via the TLS package
description:
    SSLv1 and SSLv2 are obsoleted by IETF.
    We should use TLS 1.2 (or TLS 1.1 or TLS 1.0 if necessary).
    HTTP/2 can be negotiated by ALPN.
    API docs and the README are available at
    <http://www.stackage.org/package/warp-tls>.

category:             Web, Yesod
abi:                  a496769e495e8a75bc1d8bb16d224a1f
exposed:              True
exposed-modules:      Network.Wai.Handler.WarpTLS
import-dirs:          /usr/lib/ghc-8.10.2/site-local/warp-tls-3.3.0
library-dirs:         /usr/lib/ghc-8.10.2/site-local/warp-tls-3.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.2/warp-tls-3.3.0
hs-libraries:         HSwarp-tls-3.3.0-LX9P84vetWr8NjV1La0gY0
depends:
    base-4.14.1.0 bytestring-0.10.10.0
    cryptonite-0.27-HHsLwS0rDVxGOErqbxkj0C
    data-default-class-0.1.2.0-56BXPST0gStFZdhRwxhsn8
    network-3.1.2.1-Gpsuc7SHQHF6OBh84JF5QV
    streaming-commons-0.2.2.1-As0i3gD22xP4TiGwiD93Fh
    tls-1.5.4-IB3QXPZ0KVbJ5Xf76rI49q
    tls-session-manager-0.0.4-Baq3MQyuoaCEs8XsmCNNLf
    wai-3.2.2.1-BYB2v4x1FyK8eqy5kz3dj4
    warp-3.3.13-5YMIhxHFQMs56eMisupGvu

haddock-interfaces:   /usr/share/doc/haskell-warp-tls/html/warp-tls.haddock
haddock-html:         /usr/share/doc/haskell-warp-tls/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

